<?php
if ( ! defined( 'ABSPATH' ) ) exit();

$booking_on_page = $args['booking_on_page'];
$booking_room_class = ( $booking_on_page === 'yes' ) ? ' booking-on-page' : '';
$id 		= get_the_id();
$product 	= wc_get_product( $id );
$gallery_ids 	= $product->get_gallery_image_ids();

$title 		= get_the_title();
$link 		= get_permalink( $id );
$check_in 	= isset( $args['start_date'] ) ? $args['start_date'] : '';
$check_out 	= isset( $args['end_date'] ) ? $args['end_date'] : '';
$adults 	= isset( $args['adults'] ) ? $args['adults'] : '';
$childrens 	= isset( $args['childrens'] ) ? $args['childrens'] : '';

if ( 'yes' != $booking_on_page ) {
	if ( $check_in ) {
		$link = add_query_arg( 'pickup_date', $check_in, $link );
	}
	if ( $check_out ) {
		$link = add_query_arg( 'dropoff_date', $check_out, $link );
	}
	if ( $adults ) {
		$link = add_query_arg( 'ovabrw_adults', $adults, $link );
	}
	if ( $childrens ) {
		$link = add_query_arg( 'ovabrw_childrens', $childrens, $link );
	}
}
$image_url 	= get_the_post_thumbnail_url( $id, 'single-post-thumbnail' );
$image_id 	= get_post_thumbnail_id();
$image_alt 	= '';

if ( $image_id ) {
	$image_alt 		= get_post_meta( $image_id, '_wp_attachment_image_alt', true );
	if ( empty( $image_alt ) ) {
		$image_alt = get_the_title( $image_id );
	}
}

$price = get_post_meta( $id, '_regular_price', true );
$label = esc_html__('Per night','ova-brw');

if ( $check_in && $check_out ) {
	$get_price_by_date = get_price_by_date( $id, strtotime( $check_in ), strtotime( $check_out ), array(), '', '', '' );
	$price = $get_price_by_date['line_total'] ? $get_price_by_date['line_total'] : $price;
	$label = $get_price_by_date['line_total'] ? esc_html__('Total','ova-brw') : $label;
}

$children_number   = get_post_meta( $id, 'ovabrw_children_number', true );
$adult_number      = get_post_meta( $id, 'ovabrw_adult_number', true );
$area_number       = get_post_meta( $id, 'ovabrw_acreage_number', true );
$area_unit         = get_post_meta( $id, 'ovabrw_acreage_unit', true );
$bed_number        = get_post_meta( $id, 'ovabrw_bed_number', true );
$bath_number       = get_post_meta( $id, 'ovabrw_bath_number', true );

$short_description = get_the_excerpt( $id );

$features_icons  = get_post_meta( $id, 'ovabrw_features_icons', true );
$features_label  = get_post_meta( $id, 'ovabrw_features_label', true );

?>

<div class="ovabrw-room-content2<?php esc_attr_e( $booking_room_class ); ?>">
	<div class="wrapper-room">
		<div class="room-img">
			<a href="<?php echo esc_url( $link ); ?>">
				<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
			</a>
		</div>
		<div class="room-container">
			<div class="room-price">
				<span class="price">
					<?php echo wc_price( $price );?>
				</span>
				<span class="label">
					<?php echo esc_html( $label ); ?>
				</span>
			</div>
			<h2 class="room-title">
				<?php if ( 'yes' != $booking_on_page ): ?>
					<a href="<?php echo esc_url( $link ); ?>">
						<?php echo esc_html( $title ); ?>
					</a>
				<?php else: ?>
					<?php echo esc_html( $title ); ?>
				<?php endif; ?>
			</h2>
			<ul class="room-service">
				<li>
					<i class="flaticon flaticon-manager"></i>
					<span>
					    <?php echo esc_html( $adult_number ) . ' ' . esc_html__('Adults','ova-brw');?>	
					</span>
				</li>
				<li>
					<i class="flaticon flaticon-adoption"></i>
					<span> 
						<?php echo esc_html( $children_number ) . ' ' . esc_html__('Children','ova-brw');?>	
					</span>
				</li>
				<li class="square">
					<i class="flaticon flaticon-select"></i>
					<span> 
						<?php echo esc_html( $area_number );?>	
						<?php echo esc_html( $area_unit );?><sup>2</sup>
					</span>
				</li>
			</ul>
			<p class="room-short-description">
				<?php echo esc_html( $short_description ); ?>
			</p>
			<?php if ( 'yes' != $booking_on_page ): ?>
				<div class="room-button-link" data-room-id="<?php echo esc_attr( $id ); ?>">
					<a href="<?php echo esc_url( $link ); ?>">
						<?php echo esc_html__( 'Book Now', 'ova-brw' ); ?>
					</a>
				</div>
			<?php else: ?>
				<div class="room-button" data-room-id="<?php echo esc_attr( $id ); ?>">
					<?php echo esc_html__( 'Book Now', 'ova-brw' ); ?>
				</div>
			<?php endif; ?>
		</div>
	</div>
	<div class="room-load-more" style="display: none;">
		<svg class="loader" width="50" height="50">
			<circle cx="25" cy="25" r="10" />
			<circle cx="25" cy="25" r="20" />
		</svg>
	</div>
	<div class="booking-room"></div>
</div>